import React from "react";
import "./App.css";
import { Viewer } from "@grapecity/activereports-react";
import { PdfExport,HtmlExport,TabularDataExport, XlsxExport } from "@grapecity/activereports";

function App() {
  const viewerRef = React.useRef(null);
  var currentReport = null;
  React.useEffect(() => {
    if (!viewerRef.current) return;
    var printButton = {
      key: "$print",
      iconCssClass: "mdi mdi-printer",
      text: "",
      enabled: true,
      action: function (item) {
        console.log("Print!");
        if (currentReport.parameters.PageNumbers) {
          currentReport.parameters.PageNumbers.values =
            currentReport.parameters.PageNumbers.validValues.map(
              (item) => item.value
            );
        }
        currentReport.run().then((doc) => {
          doc.print();
        });
      },
    };

    viewerRef.current.Viewer.toolbar.updateItem("$print", printButton);
  }, []);

  const reportLoaded = (e) => {
    currentReport = e.report;
    var panelButtons = document.getElementsByClassName(
      "gc-btn gc-btn--block gc-btn--with-icon gc-btn--accent gc-size-lg"
    );
    var exportButton = null;
    Array.from(panelButtons).forEach(function (element) {
      if (element.title === "Export") {
        exportButton = element;
      }
    });
    var panelStore = viewerRef.current.Viewer._viewer._panelsStore;

    exportButton.addEventListener("click",() => {
        setTimeout(() => {
          if (panelStore._state.panels[3].binder._view) {
            console.log("Ready To Export");
            panelStore._state.panels[3].binder._view.props.startExport = (
              ...args
            ) => {
              //args contain information on export type and export settings form the export panel
              console.log(args);
              var settings = args[1]; //Export Settings
              if (currentReport.parameters.PageNumbers) {
                currentReport.parameters.PageNumbers.values =
                  currentReport.parameters.PageNumbers.validValues.map(
                    (item) => item.value
                  );
              }
              currentReport.run().then((doc) => {
                if (args[0] === "pdf") {
                  PdfExport.exportDocument(doc, settings).then((result) => {
                    result.download(settings.filename);
                  });
                }
                else if (args[0] === "html") {
                  HtmlExport.exportDocument(doc, settings).then((result) => {
                    result.download(settings.filename);
                  });
                }
                else if (args[0] === "tabular-data") {
                  TabularDataExport.exportDocument(doc, settings).then((result) => {
                    result.download(settings.filename);
                  });
                }
                else if (args[0] === "xlsx") {
                  XlsxExport.exportDocument(doc, settings).then((result) => {
                    result.download(settings.filename);
                  });
                }
              });
              return true;
            };
          }
        });
      },
      false
    );
  };
  return (
    <div id="viewer-host">
      <Viewer
        ref={viewerRef}
        report={{ Uri: "PageNumberReport.rdlx-json" }}
        reportLoaded={reportLoaded}
      />
    </div>
  );
}
export default App;
